nltk.inference package
======================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.inference.api
   nltk.inference.discourse
   nltk.inference.mace
   nltk.inference.nonmonotonic
   nltk.inference.prover9
   nltk.inference.resolution
   nltk.inference.tableau

Module contents
---------------

.. automodule:: nltk.inference
   :members:
   :undoc-members:
   :show-inheritance:
